@@ -1,11 +1,11 @@
 #
-# $Id: Routing.pm,v a6d865c4550c 2015/02/04 15:13:38 gomor $
+# $Id: Routing.pm,v b00429c8f4fc 2015/02/06 17:54:06 gomor $
 #
 package Net::Routing;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.40';
 
 use base qw(Class::Gomor::Hash);
 
@@ -68,17 +68,17 @@ BEGIN {
       return $_routing_module = "Net::Routing::FreeBSD";
    }
    elsif ($^O eq 'netbsd') {
-      die("[-] Net::Routing: not implemented: \n".
-          "send 'netstat -rn' output to GomoR_at_gomor.org\n");
-   }
-   elsif ($^O eq 'openbsd') {
-      die("[-] Net::Routing: not implemented: \n".
-          "send 'netstat -rn' output to GomoR_at_gomor.org\n");
+      return $_routing_module = "Net::Routing::NetBSD";
    }
    elsif ($^O eq 'darwin') {
-      die("[-] Net::Routing: not implemented: \n".
-          "send 'netstat -rn' output to GomoR_at_gomor.org\n");
+      return $_routing_module = "Net::Routing::Darwin";
    }
+   #elsif ($^O eq 'MSWin32') {
+   #   return $_routing_module = "Net::Routing::MSWin32";
+   #}
+   #elsif ($^O eq 'openbsd') {
+   #   return $_routing_module = "Net::Routing::OpenBSD";
+   #}
 
    die("[-] Net::Routing: Operating System not supported: $^O\n");
 }
