@@ -1,16 +1,17 @@
 #
-# $Id: FreeBSD.pm,v 788e55306393 2015/02/04 16:15:59 gomor $
+# $Id: FreeBSD.pm,v 4cf58f5cf3d9 2015/02/06 17:53:16 gomor $
 #
 package Net::Routing::FreeBSD;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.40';
 
 use base qw(Net::Routing::Linux);
 
 use Net::IPv4Addr;
 use Net::IPv6Addr;
+use Net::CIDR;
 use Net::Routing qw($Error :constants);
 
 sub get {
@@ -91,7 +92,7 @@ sub _get_inet4 {
 
          # Convert FreeBSD strings to universal IP addresses
          if ($route eq 'default') {
-            $route = '0.0.0.0';
+            $route = '0.0.0.0/0';
          }
          if ($gateway =~ /^link/) {
             $gateway = '0.0.0.0';
@@ -102,6 +103,10 @@ sub _get_inet4 {
             next;
          }
 
+         # Normalize IP addresses
+         $route = Net::CIDR::range2cidr($route);    # 127.16 => 172.16/16
+         $route = Net::CIDR::cidrvalidate($route);  # 172.16/16 => 172.16.0.0/16
+
          eval {
             my ($ip1, $cidr1) = Net::IPv4Addr::ipv4_parse($route);
             my ($ip2, $cidr2) = Net::IPv4Addr::ipv4_parse($gateway);
@@ -120,7 +125,7 @@ sub _get_inet4 {
          );
 
          # Default route
-         if ($route eq '0.0.0.0') {
+         if ($route eq '0.0.0.0/0') {
             $route{default} = 1;
             $route{route} = NR_DEFAULT_ROUTE4();
          }
